craft-platforms
***************

.. image:: https://readthedocs.com/projects/canonical-craft-platforms/badge/?version=latest
    :target: https://canonical-craft-platforms.readthedocs-hosted.com/en/latest/?badge=latest
    :alt: Documentation Status

Utilities for handling platform information for `Snapcraft`_, `Charmcraft`_,
`Rockcraft`_, and other craft tools based on `Craft Application`_.

Description
-----------

Craft Platforms parses information defined in a craft recipe file such as a
``snapcraft.yaml`` file and creates a build plan. A build plan describes the
environments where the application can build artifacts and the environments
where the artifacts can run.

.. _Craft Application: https://github.com/canonical/craft-application
.. _Snapcraft: https://github.com/canonical/snapcraft
.. _Rockcraft: https://github.com/canonical/rockcraft
.. _Charmcraft: https://github.com/canonical/charmcraft
